==> thoth-messaging-0.7.0.tar.gz: thoth-messaging-0.7.0/thoth/messaging/hash_mismatch.py <==
#!/usr/bin/env python3
# thoth-messaging
# Copyright(C) 2020 Kevin Postlethwait
#
# This program is free software: you can redistribute it and / or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.


"""This is Thoth Messaging module for HashMismatchMessage."""

from .message_base import MessageBase, BaseMessageContents
from typing import List


class HashMismatchMessage(MessageBase):
    """Class used for Package Release events on Kafka topic."""

    topic_name = "thoth.package-update.hash-mismatch"

    class MessageContents(BaseMessageContents, serializer="json"):  # type: ignore
        """Class used to represent a contents of a missing-package message Kafka topic."""

        index_url: str
        package_name: str
        package_version: str
        missing_from_source: List[str]
        missing_from_database: List[str]

    def __init__(
        self,
        num_partitions: int = 1,
        replication_factor: int = 1,
        client_id: str = "thoth-messaging",
        ssl_auth: int = 1,
        bootstrap_server: str = "localhost:9092",
        topic_retention_time_second: int = 60 * 60 * 24 * 45,
        protocol: str = "SSL",
    ):
        """Initialize hash mismatch topic."""
        super(HashMismatchMessage, self).__init__(
            topic_name=self.topic_name,
            value_type=self.MessageContents,
            num_partitions=num_partitions,
            replication_factor=replication_factor,
            client_id=client_id,
            ssl_auth=ssl_auth,
            bootstrap_server=bootstrap_server,
            topic_retention_time_second=topic_retention_time_second,
            protocol=protocol,
        )

==> thoth-messaging-0.11.2.tar.gz: thoth-messaging-0.11.2/thoth/messaging/hash_mismatch.py <==
#!/usr/bin/env python3
# thoth-messaging
# Copyright(C) 2020 Kevin Postlethwait
#
# This program is free software: you can redistribute it and / or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.


"""This is Thoth Messaging module for HashMismatchMessage."""

import attr
import logging
from typing import List

from .message_base import MessageBase, BaseMessageContents

_LOGGER = logging.getLogger(__name__)


class HashMismatchMessage(MessageBase):
    """Class used for Package Release events on Kafka topic."""

    base_name = "thoth.package-update.hash-mismatch"

    @attr.s
    class MessageContents(BaseMessageContents):
        """Class used to represent a contents of a hash-mismatch message Kafka topic."""

        index_url = attr.ib(type=str)
        package_name = attr.ib(type=str)
        package_version = attr.ib(type=str)
        missing_from_source = attr.ib(type=List[str])
        missing_from_database = attr.ib(type=List[str])
        version = attr.ib(type=str, default="v1")

    def __init__(self):
        """Initialize hash mismatch topic."""
        super(HashMismatchMessage, self).__init__(
            base_name=self.base_name, value_type=self.MessageContents,
        )
